import { Token, TokenType } from "../types/token.ts";

export class Lexer {
    private position = 0;
    private tokens: Token[] = [];

    constructor(private input: string) {}

    tokenize(): Token[] {
        // Match identifiers, numbers, operators, symbols, and strings
        const regex = /([a-zA-Z_][a-zA-Z0-9_]*)|([0-9]+(?:\.[0-9]+)?)|([+\-*%!@^\/\\#_$])|([[\](){};,])|("(?:[^"\\]|\\.)*")/g;
        
        let match;
        while ((match = regex.exec(this.input)) !== null) {
            if (match[1]) {
                this.tokens.push(new Token("IDENTIFIER", match[1]));
            } else if (match[2]) {
                this.tokens.push(new Token("NUMBER", match[2]));
            } else if (match[3]) {
                this.tokens.push(new Token("OPERATOR", match[3]));
            } else if (match[4]) {
                this.tokens.push(new Token("SYMBOL", match[4]));
            } else if (match[5]) {
                this.tokens.push(new Token("STRING", match[5]));
            }
        }
        return this.tokens;
    }
} 